/* eslint no-use-before-define: ["error", { "variables": false }] */
import PropTypes from 'prop-types';
import React from 'react';
import { Linking, StyleSheet, Text, View, ViewPropTypes, TouchableOpacity } from 'react-native';
import Communications from 'react-native-communications';
// import { deviceWidth,  } from '../../../Src/Utils/Styles';
import { deviceWidth ,deviceHight} from './../../../app/styles/theme';

const WWW_URL_PATTERN = /http/i;
const url = /(http?:\/\/)[-a-zA-Z0-9@:%._\+~#=]{2,256}\/\/[-a-zA-Z0-9@:%._\+~#=]{2,256}\/[-a-zA-Z0-9@:%._\+~#=]{2,256}\/[-a-zA-Z0-9@:%._\+~#=]{2,256}\/[-a-zA-Z0-9@:%._\+~#=]{2,256}/i;
const phone = /[\+]?[(]?[0-9]{3}[)]?[-\s\.]?[0-9]{3}[-\s\.]?[0-9]{4,7}/;
const email = /\S+@\S+\.\S+/;

export default class MessageText extends React.Component {



  constructor(props) {
    super(props);
    this.onUrlPress = this.onUrlPress.bind(this);
    this.onPhonePress = this.onPhonePress.bind(this);
    this.onEmailPress = this.onEmailPress.bind(this);
  }

  shouldComponentUpdate(nextProps) {
    return this.props.currentMessage.text !== nextProps.currentMessage.text;
  }

  onUrlPress(url) {
    // When someone sends a message that includes a website address beginning with "www." (omitting the scheme),
    // react-native-parsed-text recognizes it as a valid url, but Linking fails to open due to the missing scheme.
    if (WWW_URL_PATTERN.test(url)) {
      //   this.onUrlPress(url);
      // } else {
      Linking.canOpenURL(url).then((supported) => {
        if (!supported) {
          // eslint-disable-next-line
          console.error('No handler for URL:', url);
        } else {
          Linking.openURL(url);
        }
      });
    }
  }

  onPhonePress(phone) {
    const options = ['Call', 'Text', 'Cancel'];
    const cancelButtonIndex = options.length - 1;
    this.context.actionSheet().showActionSheetWithOptions(
      {
        options,
        cancelButtonIndex,
      },
      (buttonIndex) => {
        switch (buttonIndex) {
          case 0:
            Communications.phonecall(phone, true);
            break;
          case 1:
            Communications.text(phone);
            break;
          default:
            break;
        }
      },
    );
  }

  onEmailPress(email) {
    Communications.email([email], null, null, null, null);
  }
  getFileName(text) {
    let words = text.split('/');
    return words[words.length - 1]

  }

  StyleTextPhoneAndEmail(){
    const linkStyle = StyleSheet.flatten([styles[this.props.position].link, this.props.linkStyle[this.props.position]]);

    return (
      <Text style={[
        styles[this.props.position].text,
        this.props.textStyle[this.props.position],
        this.props.customTextStyle,
        linkStyle
      ]}
      >
        {this.props.currentMessage.text}
      </Text>
    )
  }
  StyleTextURL() {
    const linkStyle = StyleSheet.flatten([styles[this.props.position].link, this.props.linkStyle[this.props.position]]);

    return (
      <Text style={[
        styles[this.props.position].text,
        this.props.textStyle[this.props.position],
        this.props.customTextStyle,
        linkStyle
      ]}
      >
        {this.getFileName(this.props.currentMessage.text)}
      </Text>
    )
  }

  StyleText() {
    return (
      <Text style={[
        styles[this.props.position].text,
        this.props.textStyle[this.props.position],
        this.props.customTextStyle,
      ]}
      >
        {this.props.currentMessage.text}
        
      </Text>
    )
  }
  getStyle(text) {
    if (url.test(text)) {
      return (
        <TouchableOpacity
          onPress={() =>
            this.onUrlPress(this.props.currentMessage.text)}
        >
          {this.StyleTextURL()}
        </TouchableOpacity>
      )
    }
    else if (email.test(text)) {
      return (
        <TouchableOpacity
          onPress={() =>
            this.onEmailPress(this.props.currentMessage.text)}
        >
          {this.StyleTextPhoneAndEmail()}

        </TouchableOpacity>)
    } else if (phone.test(text)) {
      return (
        <TouchableOpacity
          onPress={() =>
            this.onPhonePress(this.props.currentMessage.text)}
        >
          {this.StyleTextPhoneAndEmail()}

        </TouchableOpacity>)
    } else {
      return(
    this.StyleText()
      )
    }
  }

  render() {
    return (
      <View style={[styles[this.props.position].container, this.props.containerStyle[this.props.position]]}>
        {this.getStyle(this.props.currentMessage.text)}
      </View>
    );
  }

}

const textStyle = {
  fontSize: deviceWidth*0.04,
  lineHeight: deviceHight*0.04,
  marginTop: deviceHight*0.01,
  marginBottom: deviceHight*0.01,
  marginLeft: deviceHight*0.01,
  marginRight: deviceHight*0.01,
};

const styles = {
  left: StyleSheet.create({
    container: {},
    text: {
      color: 'black',
      ...textStyle,
    },
    link: {
      color: 'black',
      textDecorationLine: 'underline',
    },
  }),
  right: StyleSheet.create({
    container: {},
    text: {
      color: 'white',
      ...textStyle,
    },
    link: {
      color: 'white',
      textDecorationLine: 'underline',
    },
  }),
};

MessageText.contextTypes = {
  actionSheet: PropTypes.func,
};

MessageText.defaultProps = {
  position: 'left',
  currentMessage: {
    text: '',
  },
  containerStyle: {},
  textStyle: {},
  linkStyle: {},
  customTextStyle: {},
  textProps: {},
  parsePatterns: () => [],
};

MessageText.propTypes = {
  position: PropTypes.oneOf(['left', 'right']),
  currentMessage: PropTypes.object,
  containerStyle: PropTypes.shape({
    left: ViewPropTypes.style,
    right: ViewPropTypes.style,
  }),
  textStyle: PropTypes.shape({
    left: Text.propTypes.style,
    right: Text.propTypes.style,
  }),
  linkStyle: PropTypes.shape({
    left: Text.propTypes.style,
    right: Text.propTypes.style,
  }),
  parsePatterns: PropTypes.func,
  textProps: PropTypes.object,
  customTextStyle: Text.propTypes.style,
};

